actor_system!() { /* proc-macro */ }Expand description
Generate actor system struct and inner methods It contains LifeCycle, WhoisResponse struct too
actor_system!() { /* proc-macro */ }Generate actor system struct and inner methods It contains LifeCycle, WhoisResponse struct too