JobSpec

Struct JobSpec 

pub struct JobSpec { /* private fields */ }
A specification for a job that can be executed by a worker thread. The max_iter is the maximum number of iterations the job will be executed. If max_iter is None, the job will be executed indefinitely. The interval is the time between two iterations of the job. If the interval is None, the job will be executed only once. The start_at is the time when the job will start executing. If the start_at is in the past, the job will start executing immediately.

Implementations

Source

impl JobSpec

pub fn new( max_iter: Option<usize>, interval: Option<Duration>, start_at: SystemTime, ) -> Self

pub fn max_iter(&self) -> Option<usize>

pub fn start_at(&self) -> SystemTime

pub fn interval(&self) -> Option<Duration>