pub struct JobSpec { /* private fields */ }Expand description
A specification for a job that can be executed by a worker thread.
The max_iter is the maximum number of iterations the job will be executed.
If max_iter is None, the job will be executed indefinitely.
The interval is the time between two iterations of the job.
If the interval is None, the job will be executed only once.
The start_at is the time when the job will start executing.
If the start_at is in the past, the job will start executing immediately.
Implementations