Message

Struct Message 

pub struct Message<T: Actor> { /* private fields */ }
A message that can be sent to a worker thread.

You don’t need to implement this trait. It is a wrapper for data that you sent. This message contains the data to be processed and a result channel. The result channel is used to send the result back to the sender.

Implementations

Source

impl<T> Message<T>
where T: Actor,

pub fn new( inner: Arc<<T as Actor>::Message>, result_tx: Option<Sender<<T as Actor>::Result>>, ) -> Self

pub fn inner(&self) -> Arc<<T as Actor>::Message>

pub fn result_tx(&mut self) -> Option<Sender<<T as Actor>::Result>>