pub struct Message<T: Actor> { /* private fields */ }Expand description
A message that can be sent to a worker thread.
You don’t need to implement this trait. It is a wrapper for data that you sent. This message contains the data to be processed and a result channel. The result channel is used to send the result back to the sender.
Implementations