pub struct Message { /* private fields */ }Expand description
A message that can be sent to a worker thread.
You don’t need to implement this trait. It is a wrapper for rmp_serde encoded data that you sent. This message contains the data to be processed and an result channel. The result channel is used to send the result back to the sender.
Implementations